gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-quickjs-tart] branch master updated: cleanup


From: gnunet
Subject: [taler-quickjs-tart] branch master updated: cleanup
Date: Wed, 28 Feb 2024 12:25:14 +0100

This is an automated email from the git hooks/post-receive script.

marc-stibane pushed a commit to branch master
in repository quickjs-tart.

The following commit(s) were added to refs/heads/master by this push:
     new 24a009c  cleanup
24a009c is described below

commit 24a009cc08abfebc3d169c4fd55495335185634a
Author: Marc Stibane <marc@taler.net>
AuthorDate: Wed Feb 28 12:25:01 2024 +0100

    cleanup
---
 taler_wallet_core_lib.c              |  4 ++--
 taler_wallet_core_lib.h              | 13 +++++--------
 taler_wallet_core_lib_preprocessed.h | 14 +++++---------
 3 files changed, 12 insertions(+), 19 deletions(-)

diff --git a/taler_wallet_core_lib.c b/taler_wallet_core_lib.c
index 1f89670..1cfaf5c 100644
--- a/taler_wallet_core_lib.c
+++ b/taler_wallet_core_lib.c
@@ -329,8 +329,8 @@ TALER_start_redirect_std(TALER_LogFn logfn, void *cls)
 }
 
 void
-TALER_set_http_client_implementation(struct TALER_WALLET_Instance *instance,
+TALER_set_http_client_implementation(struct TALER_WALLET_Instance *twi,
                                      struct JSHttpClientImplementation *impl)
 {
-  instance->http_impl = impl;
+  twi->http_impl = impl;
 }
diff --git a/taler_wallet_core_lib.h b/taler_wallet_core_lib.h
index 660690d..3620d1f 100644
--- a/taler_wallet_core_lib.h
+++ b/taler_wallet_core_lib.h
@@ -78,7 +78,6 @@ TALER_WALLET_set_message_handler(struct TALER_WALLET_Instance 
*twi,
                                  TALER_WALLET_MessageHandlerFn handler_f,
                                  void *handler_p);
 
-
 /**
  * Set a handler for log messages from wallet-core.
  * Must be called before the wallet runs.
@@ -90,7 +89,6 @@ TALER_WALLET_set_log_handler(struct TALER_WALLET_Instance 
*twi,
                              TALER_WALLET_LogHandlerFn handler_f,
                              void *handler_p);
 
-
 /**
  * Set/override the JS file with the wallet-core implementation.
  * Must be called before the wallet runs.
@@ -143,7 +141,7 @@ TALER_WALLET_join(struct TALER_WALLET_Instance *twi);
  * @param stream NOT YET IMPLEMENTED: indicator for the stream that
  *               the message is coming from,
  */
-typedef void (*TALER_LogFn)(void *cls, int stream, const char *msg);
+typedef void (*TALER_LogFn)(void *handler_p, int stream, const char *msg);
 
 /**
  * Redirect stderr and stdout to a function.
@@ -153,17 +151,16 @@ typedef void (*TALER_LogFn)(void *cls, int stream, const 
char *msg);
  * @return 0 on success, error code otherwise
  */
 int
-TALER_start_redirect_std(TALER_LogFn logfn, void *cls);
-
+TALER_start_redirect_std(TALER_LogFn logfn, void *handler_p);
 
 /**
  * Set the HTTP client implementation to be used by the wallet.
  *
  * @param instance wallet-core instance
  * @param HTTP client implementation
  */
 void
-TALER_set_http_client_implementation(struct TALER_WALLET_Instance *instance,
+TALER_set_http_client_implementation(struct TALER_WALLET_Instance *twi,
                                      struct JSHttpClientImplementation *impl);
 
 #endif /*_TALER_WALLET_LIB_H */
@@ -153,17 +151,16 @@ typedef void (*TALER_LogFn)(void *cls, int stream, const 
  * Set the HTTP client implementation to be used by the wallet.
  *
- * @param instance wallet-core instance
- * @param HTTP client implementation
+ * @param twi wallet-core instance
+ * @param impl HTTP client implementation
  */
 void
diff --git a/taler_wallet_core_lib_preprocessed.h 
b/taler_wallet_core_lib_preprocessed.h
index 336b650..f8872c8 100644
--- a/taler_wallet_core_lib_preprocessed.h
+++ b/taler_wallet_core_lib_preprocessed.h
@@ -228,7 +228,6 @@ struct JSHttpClientImplementation {
   JSHttpReqCancelFn req_cancel;
 };
 
-
 struct JSHttpClientImplementation *
 js_curl_http_client_create(void);
 
@@ -288,7 +287,6 @@ TALER_WALLET_set_message_handler(struct 
TALER_WALLET_Instance *twi,
                                  TALER_WALLET_MessageHandlerFn handler_f,
                                  void *handler_p);
 
-
 /**
  * Set a handler for log messages from wallet-core.
  * Must be called before the wallet runs.
@@ -300,7 +298,6 @@ TALER_WALLET_set_log_handler(struct TALER_WALLET_Instance 
*twi,
                              TALER_WALLET_LogHandlerFn handler_f,
                              void *handler_p);
 
-
 /**
  * Set/override the JS file with the wallet-core implementation.
  * Must be called before the wallet runs.
@@ -353,7 +350,7 @@ TALER_WALLET_join(struct TALER_WALLET_Instance *twi);
  * @param stream NOT YET IMPLEMENTED: indicator for the stream that
  *               the message is coming from,
  */
-typedef void (*TALER_LogFn)(void *cls, int stream, const char *msg);
+typedef void (*TALER_LogFn)(void *handler_p, int stream, const char *msg);
 
 /**
  * Redirect stderr and stdout to a function.
@@ -363,17 +360,16 @@ typedef void (*TALER_LogFn)(void *cls, int stream, const 
char *msg);
  * @return 0 on success, error code otherwise
  */
 int
-TALER_start_redirect_std(TALER_LogFn logfn, void *cls);
-
+TALER_start_redirect_std(TALER_LogFn logfn, void *handler_p);
 
 /**
  * Set the HTTP client implementation to be used by the wallet.
  *
  * @param instance wallet-core instance
  * @param HTTP client implementation
  */
 void
-TALER_set_http_client_implementation(struct TALER_WALLET_Instance *instance,
+TALER_set_http_client_implementation(struct TALER_WALLET_Instance *twi,
                                      struct JSHttpClientImplementation *impl);
 
 #endif /*_TALER_WALLET_LIB_H */
@@ -363,17 +360,16 @@ typedef void (*TALER_LogFn)(void *cls, int stream, const 
  * Set the HTTP client implementation to be used by the wallet.
  *
- * @param instance wallet-core instance
- * @param HTTP client implementation
+ * @param twi wallet-core instance
+ * @param impl HTTP client implementation
  */
 void

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]